@@ -1,11 +1,12 @@
 use {
-    super::colors,
     crate::{
         errors::InvalidSkinError,
     },
-    crokey::crossterm::style::Color,
     ahash::AHashMap,
+    crokey::crossterm::style::Color,
+    lazy_regex::*,
     std::convert::TryFrom,
+    termimad::parse_color,
 };
 
 
@@ -23,7 +24,8 @@ impl ExtColorMap {
         self.map.get(ext).copied()
     }
     pub fn set(&mut self, ext: String, raw_color: &str) -> Result<(), InvalidSkinError> {
-        if let Some(color) = colors::parse(raw_color)? {
+        if !regex_is_match!("^none$"i, raw_color) {
+            let color = parse_color(raw_color)?;
             self.map.insert(ext, color);
         }
         Ok(())
